@@ -25,12 +25,21 @@ class SharedBackendConf(SharedBackendConfUtils):
     # Getters
     #
 
-    def backendClusterMode(self):
-        return self._jconf.backendClusterMode()
+    def cloudName(self):
+        return self._get_option(self._jconf.cloudName())
 
     def isH2OReplEnabled(self):
         return self._jconf.isH2OReplEnabled()
 
+    def backendClusterMode(self):
+        return self._jconf.backendClusterMode()
+
+    def isProgressBarEnabled(self):
+        return self._jconf.isProgressBarEnabled()
+
+    def isModelPrintAfterTrainingEnabled(self):
+        return self._jconf.isModelPrintAfterTrainingEnabled()
+
     def scalaIntDefaultNum(self):
         return self._jconf.scalaIntDefaultNum()
 
@@ -190,9 +199,6 @@ class SharedBackendConf(SharedBackendConfUtils):
     def restApiTimeout(self):
         return self._jconf.restApiTimeout()
 
-    def cloudName(self):
-        return self._get_option(self._jconf.cloudName())
-
     def nthreads(self):
         return self._jconf.nthreads()
 
@@ -209,12 +215,12 @@ class SharedBackendConf(SharedBackendConfUtils):
         self._jconf.setExternalClusterMode()
         return self
 
-    def setCloudName(self, value):
-        self._jconf.setCloudName(value)
+    def setCloudName(self, arg0):
+        self._jconf.setCloudName(arg0)
         return self
 
-    def setNthreads(self, value):
-        self._jconf.setNthreads(value)
+    def setNthreads(self, arg0):
+        self._jconf.setNthreads(arg0)
         return self
 
     def setReplEnabled(self):
@@ -225,8 +231,24 @@ class SharedBackendConf(SharedBackendConfUtils):
         self._jconf.setReplDisabled()
         return self
 
-    def setDefaultNumReplSessions(self, value):
-        self._jconf.setDefaultNumReplSessions(value)
+    def setProgressBarEnabled(self):
+        self._jconf.setProgressBarEnabled()
+        return self
+
+    def setProgressBarDisabled(self):
+        self._jconf.setProgressBarDisabled()
+        return self
+
+    def setModelPrintAfterTrainingEnabled(self):
+        self._jconf.setModelPrintAfterTrainingEnabled()
+        return self
+
+    def setModelPrintAfterTrainingDisabled(self):
+        self._jconf.setModelPrintAfterTrainingDisabled()
+        return self
+
+    def setDefaultNumReplSessions(self, arg0):
+        self._jconf.setDefaultNumReplSessions(arg0)
         return self
 
     def setClusterTopologyListenerEnabled(self):
@@ -253,20 +275,20 @@ class SharedBackendConf(SharedBackendConfUtils):
         self._jconf.setFailOnUnsupportedSparkParamDisabled()
         return self
 
-    def setJks(self, value):
-        self._jconf.setJks(value)
+    def setJks(self, arg0):
+        self._jconf.setJks(arg0)
         return self
 
-    def setJksPass(self, value):
-        self._jconf.setJksPass(value)
+    def setJksPass(self, arg0):
+        self._jconf.setJksPass(arg0)
         return self
 
-    def setJksAlias(self, value):
-        self._jconf.setJksAlias(value)
+    def setJksAlias(self, arg0):
+        self._jconf.setJksAlias(arg0)
         return self
 
-    def setSslCACert(self, value):
-        self._jconf.setSslCACert(value)
+    def setSslCACert(self, arg0):
+        self._jconf.setSslCACert(arg0)
         return self
 
     def setHashLoginEnabled(self):
@@ -293,20 +315,20 @@ class SharedBackendConf(SharedBackendConfUtils):
         self._jconf.setKerberosLoginDisabled()
         return self
 
-    def setLoginConf(self, value):
-        self._jconf.setLoginConf(value)
+    def setLoginConf(self, arg0):
+        self._jconf.setLoginConf(arg0)
         return self
 
-    def setUserName(self, value):
-        self._jconf.setUserName(value)
+    def setUserName(self, arg0):
+        self._jconf.setUserName(arg0)
         return self
 
-    def setPassword(self, value):
-        self._jconf.setPassword(value)
+    def setPassword(self, arg0):
+        self._jconf.setPassword(arg0)
         return self
 
-    def setSslConf(self, value):
-        self._jconf.setSslConf(value)
+    def setSslConf(self, arg0):
+        self._jconf.setSslConf(arg0)
         return self
 
     def setAutoFlowSslEnabled(self):
@@ -317,32 +339,32 @@ class SharedBackendConf(SharedBackendConfUtils):
         self._jconf.setAutoFlowSslDisabled()
         return self
 
-    def setLogLevel(self, value):
-        self._jconf.setLogLevel(value)
+    def setLogLevel(self, arg0):
+        self._jconf.setLogLevel(arg0)
         return self
 
-    def setLogDir(self, value):
-        self._jconf.setLogDir(value)
+    def setLogDir(self, arg0):
+        self._jconf.setLogDir(arg0)
         return self
 
-    def setBackendHeartbeatInterval(self, value):
-        self._jconf.setBackendHeartbeatInterval(value)
+    def setBackendHeartbeatInterval(self, arg0):
+        self._jconf.setBackendHeartbeatInterval(arg0)
         return self
 
-    def setCloudTimeout(self, value):
-        self._jconf.setCloudTimeout(value)
+    def setCloudTimeout(self, arg0):
+        self._jconf.setCloudTimeout(arg0)
         return self
 
-    def setNodeNetworkMask(self, value):
-        self._jconf.setNodeNetworkMask(value)
+    def setNodeNetworkMask(self, arg0):
+        self._jconf.setNodeNetworkMask(arg0)
         return self
 
-    def setStacktraceCollectorInterval(self, value):
-        self._jconf.setStacktraceCollectorInterval(value)
+    def setContextPath(self, arg0):
+        self._jconf.setContextPath(arg0)
         return self
 
-    def setContextPath(self, value):
-        self._jconf.setContextPath(value)
+    def setStacktraceCollectorInterval(self, arg0):
+        self._jconf.setStacktraceCollectorInterval(arg0)
         return self
 
     def setFlowScalaCellAsyncEnabled(self):
@@ -353,36 +375,36 @@ class SharedBackendConf(SharedBackendConfUtils):
         self._jconf.setFlowScalaCellAsyncDisabled()
         return self
 
-    def setMaxParallelScalaCellJobs(self, value):
-        self._jconf.setMaxParallelScalaCellJobs(value)
+    def setMaxParallelScalaCellJobs(self, arg0):
+        self._jconf.setMaxParallelScalaCellJobs(arg0)
         return self
 
-    def setInternalPortOffset(self, value):
-        self._jconf.setInternalPortOffset(value)
+    def setInternalPortOffset(self, arg0):
+        self._jconf.setInternalPortOffset(arg0)
         return self
 
-    def setBasePort(self, value):
-        self._jconf.setBasePort(value)
+    def setBasePort(self, arg0):
+        self._jconf.setBasePort(arg0)
         return self
 
-    def setMojoDestroyTimeout(self, value):
-        self._jconf.setMojoDestroyTimeout(value)
+    def setMojoDestroyTimeout(self, arg0):
+        self._jconf.setMojoDestroyTimeout(arg0)
         return self
 
-    def setExtraProperties(self, value):
-        self._jconf.setExtraProperties(value)
+    def setExtraProperties(self, arg0):
+        self._jconf.setExtraProperties(arg0)
         return self
 
-    def setFlowExtraHttpHeaders(self, value):
-        self._jconf.setFlowExtraHttpHeaders(value)
+    def setFlowExtraHttpHeaders(self, *args):
+        self._jconf.setFlowExtraHttpHeaders(*args)
         return self
 
-    def setFlowProxyRequestMaxSize(self, value):
-        self._jconf.setFlowProxyRequestMaxSize(value)
+    def setFlowProxyRequestMaxSize(self, arg0):
+        self._jconf.setFlowProxyRequestMaxSize(arg0)
         return self
 
-    def setFlowProxyResponseMaxSize(self, value):
-        self._jconf.setFlowProxyResponseMaxSize(value)
+    def setFlowProxyResponseMaxSize(self, arg0):
+        self._jconf.setFlowProxyResponseMaxSize(arg0)
         return self
 
     def setInternalSecureConnectionsEnabled(self):
@@ -401,16 +423,16 @@ class SharedBackendConf(SharedBackendConfUtils):
         self._jconf.setInsecureXGBoostDenied()
         return self
 
-    def setFlowDir(self, value):
-        self._jconf.setFlowDir(value)
+    def setFlowDir(self, arg0):
+        self._jconf.setFlowDir(arg0)
         return self
 
-    def setClientIp(self, value):
-        self._jconf.setClientIp(value)
+    def setClientIp(self, arg0):
+        self._jconf.setClientIp(arg0)
         return self
 
-    def setClientWebPort(self, value):
-        self._jconf.setClientWebPort(value)
+    def setClientWebPort(self, arg0):
+        self._jconf.setClientWebPort(arg0)
         return self
 
     def setClientVerboseEnabled(self):
@@ -421,20 +443,20 @@ class SharedBackendConf(SharedBackendConfUtils):
         self._jconf.setClientVerboseDisabled()
         return self
 
-    def setClientNetworkMask(self, value):
-        self._jconf.setClientNetworkMask(value)
+    def setClientNetworkMask(self, arg0):
+        self._jconf.setClientNetworkMask(arg0)
         return self
 
-    def setClientFlowBaseurlOverride(self, value):
-        self._jconf.setClientFlowBaseurlOverride(value)
+    def setClientFlowBaseurlOverride(self, arg0):
+        self._jconf.setClientFlowBaseurlOverride(arg0)
         return self
 
-    def setClientCheckRetryTimeout(self, value):
-        self._jconf.setClientCheckRetryTimeout(value)
+    def setClientCheckRetryTimeout(self, arg0):
+        self._jconf.setClientCheckRetryTimeout(arg0)
         return self
 
-    def setVerifySslCertificates(self, value):
-        self._jconf.setVerifySslCertificates(value)
+    def setVerifySslCertificates(self, arg0):
+        self._jconf.setVerifySslCertificates(arg0)
         return self
 
     def setSslHostnameVerificationInInternalRestConnectionsEnabled(self):
@@ -461,26 +483,26 @@ class SharedBackendConf(SharedBackendConfUtils):
         self._jconf.setKerberizedHiveDisabled()
         return self
 
-    def setHiveHost(self, value):
-        self._jconf.setHiveHost(value)
+    def setHiveHost(self, arg0):
+        self._jconf.setHiveHost(arg0)
         return self
 
-    def setHivePrincipal(self, value):
-        self._jconf.setHivePrincipal(value)
+    def setHivePrincipal(self, arg0):
+        self._jconf.setHivePrincipal(arg0)
         return self
 
-    def setHiveJdbcUrlPattern(self, value):
-        self._jconf.setHiveJdbcUrlPattern(value)
+    def setHiveJdbcUrlPattern(self, arg0):
+        self._jconf.setHiveJdbcUrlPattern(arg0)
         return self
 
-    def setHiveToken(self, value):
-        self._jconf.setHiveToken(value)
+    def setHiveToken(self, arg0):
+        self._jconf.setHiveToken(arg0)
         return self
 
-    def setIcedDir(self, value):
-        self._jconf.setIcedDir(value)
+    def setIcedDir(self, arg0):
+        self._jconf.setIcedDir(arg0)
         return self
 
-    def setRestApiTimeout(self, value):
-        self._jconf.setRestApiTimeout(value)
+    def setRestApiTimeout(self, arg0):
+        self._jconf.setRestApiTimeout(arg0)
         return self
