@@ -31,6 +31,7 @@ class H2ODRFClassifier(H2ODRF):
                  columnsToCategorical=[],
                  keepBinaryModels=False,
                  withContributions=False,
+                 dataFrameSerializer="ai.h2o.sparkling.utils.JSONDataFrameSerializer",
                  withLeafNodeAssignments=False,
                  namedMojoOutputColumns=True,
                  convertInvalidNumbersToNa=False,
@@ -41,7 +42,6 @@ class H2ODRFClassifier(H2ODRF):
                  convertUnknownCategoricalLevelsToNa=False,
                  splitRatio=1.0,
                  withStageResults=False,
-                 withDetailedPredictionCol=True,
                  mtries=-1,
                  binomialDoubleTrees=False,
                  sampleRate=0.632,
