@@ -32,6 +32,7 @@ class H2OGAMRegressor(H2OGAM):
                  columnsToCategorical=[],
                  keepBinaryModels=False,
                  withContributions=False,
+                 dataFrameSerializer="ai.h2o.sparkling.utils.JSONDataFrameSerializer",
                  withLeafNodeAssignments=False,
                  namedMojoOutputColumns=True,
                  convertInvalidNumbersToNa=False,
@@ -42,7 +43,6 @@ class H2OGAMRegressor(H2OGAM):
                  convertUnknownCategoricalLevelsToNa=False,
                  splitRatio=1.0,
                  withStageResults=False,
-                 withDetailedPredictionCol=True,
                  seed=-1,
                  family="AUTO",
                  tweedieVariancePower=0.0,
@@ -76,6 +76,7 @@ class H2OGAMRegressor(H2OGAM):
                  computePValues=False,
                  removeCollinearCols=False,
                  numKnots=None,
+                 splineOrders=None,
                  scale=None,
                  bs=None,
                  keepGamCols=False,
