@@ -45,10 +45,10 @@ class H2OWordEmbeddingModel(ModelBase):
         Transform words (or sequences of words) to vectors using a word2vec model.
 
         :param str words: An H2OFrame made of a single column containing source words.
-        :param str aggregate_method: Specifies how to aggregate sequences of words. If method is `NONE`
-               then no aggregation is performed and each input word is mapped to a single word-vector.
-               If method is 'AVERAGE' then input is treated as sequences of words delimited by NA.
-               Each word of a sequences is internally mapped to a vector and vectors belonging to
+        :param str aggregate_method: Specifies how to aggregate sequences of words. If your method is ```NONE```,
+               no aggregation is performed and each input word is mapped to a single word-vector.
+               If your method is ``'AVERAGE'``, input is treated as sequences of words delimited by NA.
+               Each word of a sequences is internally mapped to a vector, and vectors belonging to
                the same sentence are averaged and returned in the result.
 
         :returns: the approximate reconstruction of the training data.
@@ -89,4 +89,4 @@ class H2OWordEmbeddingModel(ModelBase):
         >>> word_embeddings.names = w2v_frame.names
         >>> word_embeddings.as_data_frame().equals(word_embeddings.as_data_frame())
         """
-        return h2o.H2OFrame._expr(expr=ExprNode("word2vec.to.frame", self))
\ No newline at end of file
+        return h2o.H2OFrame._expr(expr=ExprNode("word2vec.to.frame", self))
